package treeview;

import java.awt.Image;
import java.awt.Rectangle;

public class TreeViewNode extends SiblingChildTree {
   protected ImageSet m_isImages;
   protected ImageSetSource m_issrcSource;
   protected String m_strLabel;
   protected Rectangle m_rectBounds;
   protected boolean m_bCollapsed = false;
   protected boolean m_bSelected = false;
   protected boolean m_bUseSpecificImgIndex = false;
   protected int m_nImageIndex = -1;

   public void doDblClick() {
   }

   public void moveBounds(int var1, int var2) {
      this.m_rectBounds.x = var1;
      this.m_rectBounds.y = var2;
   }

   public boolean getCollapsedState() {
      return this.m_bCollapsed;
   }

   public void setCollapsedState(boolean var1) {
      this.m_bCollapsed = var1;
   }

   public TreeViewNode nextNode(boolean var1) {
      if ((!var1 || !this.m_bCollapsed) && super.child != null) {
         return (TreeViewNode)super.child;
      } else if (super.sibling_right != null) {
         return (TreeViewNode)super.sibling_right;
      } else {
         for(SiblingChildTree var2 = super.parent; var2 != null; var2 = var2.parent) {
            if (var2.sibling_right != null) {
               return (TreeViewNode)var2.sibling_right;
            }
         }

         return null;
      }
   }

   public void select(boolean var1) {
      this.m_bSelected = var1;
   }

   public void collapseTree() {
      for(TreeViewNode var1 = this; var1 != null; var1 = (TreeViewNode)var1.sibling_right) {
         var1.m_bCollapsed = true;

         try {
            ((TreeViewNode)var1.child).collapseTree();
         } catch (NullPointerException var2) {
         }
      }

   }

   public Rectangle getBounds() {
      return new Rectangle(this.m_rectBounds.x, this.m_rectBounds.y, this.m_rectBounds.width, this.m_rectBounds.height);
   }

   public void setBounds(int var1, int var2, int var3, int var4) {
      this.m_rectBounds.reshape(var1, var2, var3, var4);
   }

   public void setBounds(Rectangle var1) {
      this.m_rectBounds.reshape(var1.x, var1.y, var1.width, var1.height);
   }

   public int getWidth() {
      return this.m_rectBounds.width;
   }

   public int getImageIndex() {
      return this.m_nImageIndex;
   }

   public void setImageIndex(int var1) {
      this.m_nImageIndex = var1;
   }

   public void setImageSetSource(ImageSetSource var1) {
      this.m_issrcSource = var1;
   }

   public ImageSetSource getImageSetSource() {
      return this.m_issrcSource;
   }

   public void expandTree() {
      for(TreeViewNode var1 = this; var1 != null; var1 = (TreeViewNode)var1.sibling_right) {
         var1.m_bCollapsed = false;

         try {
            ((TreeViewNode)var1.child).expandTree();
         } catch (NullPointerException var2) {
         }
      }

   }

   public TreeViewNode() {
      this.m_isImages = null;
      this.m_issrcSource = null;
      this.m_strLabel = null;
      this.m_rectBounds = new Rectangle();
   }

   public TreeViewNode(String var1) {
      this.m_isImages = null;
      this.m_issrcSource = null;
      this.m_strLabel = var1;
      this.m_rectBounds = new Rectangle();
   }

   public TreeViewNode(ImageSet var1) {
      this.m_isImages = var1;
      this.m_issrcSource = null;
      this.m_strLabel = null;
      this.m_rectBounds = new Rectangle();
   }

   public TreeViewNode(ImageSetSource var1) {
      this.m_isImages = null;
      this.m_issrcSource = var1;
      this.m_strLabel = null;
      this.m_rectBounds = new Rectangle();
   }

   public TreeViewNode(String var1, ImageSetSource var2) {
      this.m_isImages = null;
      this.m_issrcSource = var2;
      this.m_strLabel = var1;
      this.m_rectBounds = new Rectangle();
   }

   public TreeViewNode(String var1, ImageSet var2) {
      this.m_isImages = var2;
      this.m_issrcSource = null;
      this.m_strLabel = var1;
      this.m_rectBounds = new Rectangle();
   }

   public boolean isSelected() {
      return this.m_bSelected;
   }

   public TreeViewNode prevNode(boolean var1) {
      if (super.sibling_left == null) {
         return super.parent != null ? (TreeViewNode)this.lastBeforeMatch((TreeViewNode)super.parent, var1) : null;
      } else if (var1 && ((TreeViewNode)super.sibling_left).m_bCollapsed) {
         return (TreeViewNode)this.lastBeforeMatch((TreeViewNode)super.sibling_left, var1);
      } else {
         SiblingChildTree var2 = super.sibling_left.child;
         if (var2 == null) {
            return (TreeViewNode)this.lastBeforeMatch((TreeViewNode)super.sibling_left, var1);
         } else {
            while(var2.sibling_right != null) {
               var2 = var2.sibling_right;
            }

            return (TreeViewNode)this.lastBeforeMatch((TreeViewNode)var2, var1);
         }
      }
   }

   private SiblingChildTree lastBeforeMatch(TreeViewNode var1, boolean var2) {
      TreeViewNode var3 = null;

      do {
         if (var3 != null) {
            var1 = var3;
         }

         var3 = var1.nextNode(var2);
      } while(var3 != this);

      return var1;
   }

   public Image getCurrentImage() {
      ImageSet var1 = this.m_isImages;
      if (var1 == null) {
         if (this.m_issrcSource != null) {
            var1 = this.m_issrcSource.getImages();
         }

         if (var1 == null) {
            return null;
         }
      }

      try {
         if (this.m_bUseSpecificImgIndex) {
            try {
               return var1.getImage(this.m_nImageIndex);
            } catch (IndexOutOfBoundsException var2) {
               return null;
            }
         } else if (super.child == null) {
            if (this.m_bSelected) {
               try {
                  return var1.getImage(3);
               } catch (IndexOutOfBoundsException var3) {
                  return var1.getImage(0);
               }
            } else {
               return var1.getImage(0);
            }
         } else if (this.m_bSelected) {
            try {
               return this.m_bCollapsed ? var1.getImage(4) : var1.getImage(5);
            } catch (IndexOutOfBoundsException var4) {
               return this.m_bCollapsed ? var1.getImage(1) : var1.getImage(2);
            }
         } else {
            return this.m_bCollapsed ? var1.getImage(1) : var1.getImage(2);
         }
      } catch (IndexOutOfBoundsException var5) {
         return null;
      }
   }

   public boolean getUseSpecifiedImageIndex() {
      return this.m_bUseSpecificImgIndex;
   }

   public void setUseSpecifiedImageIndex(boolean var1) {
      this.m_bUseSpecificImgIndex = var1;
   }

   public int getHeight() {
      return this.m_rectBounds.height;
   }

   public ImageSet getImages() {
      return this.m_isImages;
   }

   public void setImages(ImageSet var1) {
      this.m_isImages = var1;
   }

   public boolean isInside(int var1, int var2) {
      return this.m_rectBounds.inside(var1, var2);
   }

   public String getLabel() {
      return this.m_strLabel;
   }

   public void setLabel(String var1) {
      this.m_strLabel = var1;
   }

   public void doAction() {
   }
}
